@@ -616,7 +616,14 @@ app_will_quit_cb (GtkosxApplication *app, gpointer data)
 static gboolean
 app_open_file_cb (GtkosxApplication *app, gchar *path, gpointer user_data)
 {
-  g_print ("File open event for %s", path);
+  GtkWindow *parent = GTK_WINDOW(user_data);
+  GtkDialog *dialog = gtk_message_dialog_new (parent,
+					      GTK_DIALOG_DESTROY_WITH_PARENT,
+					      GTK_MESSAGE_INFO,
+					      GTK_BUTTONS_CLOSE,
+					      "File open event for %s", path);
+  gtk_dialog_run (dialog);
+  gtk_widget_destroy (dialog);
   return FALSE;
 }
 
@@ -850,7 +857,7 @@ main (int argc, char **argv)
     g_signal_connect (theApp, "NSApplicationWillTerminate",
                       G_CALLBACK (app_will_quit_cb), NULL);
     g_signal_connect (theApp, "NSApplicationOpenFile",
-                      G_CALLBACK (app_open_file_cb), NULL);
+                      G_CALLBACK (app_open_file_cb), (gconstpointer)window1);
   }
 # ifndef QUARTZ_HANDLERS
   gtkosx_application_set_use_quartz_accelerators (theApp, FALSE);
